News
====

Lists of changes between versions.

1.3.1
-----
* Patch: Correct aiohttp requirement.

1.3.0
-----
* Minor: Upgrade versions concurrently.

1.2.0
------
* Minor: Downgrade if newest version is yanked.

1.1.0
-----
* Minor: Support reading settings from pyproject.toml.
* Minor: Accepts atmost a single input and output file.
* Minor: Pypy support.

1.0.0
-----
* Minor: Support Python 3.13.
* Minor: Use cli from bouillon instead of boil.py.
* Minor: Use brundle to run linters.

0.3.0
-----
* Initial release #2.

0.2.0
------
* Initial release.
